@@ -1,18 +1,17 @@
 use strict;
 package Event::io;
-use vars qw(@ISA @EXPORT_OK);
+use vars qw(@ISA @EXPORT_OK @ATTRIBUTE);
 @ISA = qw(Event::Watcher Exporter);
 @EXPORT_OK = qw(R W E T);  # bit constants
+@ATTRIBUTE = qw(poll fd timeout);
 
 'Event::Watcher'->register;
 
 sub new {
 #    lock %Event::;
 
-    shift if @_ & 1;
+    my $o = allocate(shift);
     my %arg = @_;
-
-    my $o = allocate();
     $o->init(\%arg);
     $o->start;
     $o;
